@@ -23,10 +23,9 @@ from tpDcc.libs.qt.core import qtutils
 
 import artellapipe
 from artellapipe.core import defines
-from artellapipe.libs import artella
 from artellapipe.libs.artella.core import artellalib
 
-LOGGER = logging.getLogger()
+LOGGER = logging.getLogger('artellapipe')
 
 
 class AbstractFile(object):
@@ -239,9 +238,9 @@ class AbstractFile(object):
                     extra_dict[k] = v
                 else:
                     if v and v != extra_dict[k]:
-                        LOGGER.info('Updating Template Dict from file type specific value: {} | {} >>> {}'.format(
-                            k, extra_dict[k], file_type_dict[k]
-                        ))
+                        LOGGER.info(
+                            'Updating Template Dict from file type specific value: {} | {} >>> {}'.format(
+                                k, extra_dict[k], file_type_dict[k]))
                         extra_dict[k] = v
 
         if not template:
@@ -272,7 +271,8 @@ class AbstractFile(object):
                         template_dict['version_folder'] = version
                     else:
                         if only_local:
-                            LOGGER.warning('No local version "{}" found for File Type: "{}"'.format(version, file_type))
+                            LOGGER.warning(
+                                'No local version "{}" found for File Type: "{}"'.format(version, file_type))
                             return None
                         else:
                             template_dict['version_folder'] = version
@@ -344,9 +344,9 @@ class AbstractFile(object):
                     extension = file_type_extensions[0]
 
         if extension not in available_extensions:
-            LOGGER.warning('Impossible to reference file with extension "{}". Supported extensions: {}'.format(
-                extension, available_extensions
-            ))
+            LOGGER.warning(
+                'Impossible to reference file with extension "{}". Supported extensions: {}'.format(
+                    extension, available_extensions))
             return False
 
         file_types = artellapipe.FilesMgr().get_file_types_by_extension(extension)
@@ -372,9 +372,9 @@ class AbstractFile(object):
                 if ft.FILE_TYPE != file_type:
                     continue
                 if reference:
-                    return ft(self).import_file(sync=sync, reference=True)
+                    return ft(self).import_file(status=status, sync=sync, reference=True)
                 else:
-                    return ft(self).import_file(sync=sync, reference=False)
+                    return ft(self).import_file(status=status, sync=sync, reference=False)
 
     def supports_file_type(self, file_type, status=defines.ArtellaFileStatus.ALL):
         """
@@ -435,7 +435,8 @@ class AbstractFile(object):
 
         artella_url = self.get_artella_url()
         if not artella_url:
-            LOGGER.warning('Impossible to open Artella URL for asset "{}" : "{}"'.format(self.get_name(), artella_url))
+            LOGGER.warning(
+                'Impossible to open Artella URL for asset "{}" : "{}"'.format(self.get_name(), artella_url))
             return None
 
         webbrowser.open(artella_url)
@@ -733,9 +734,10 @@ class AbstractAsset(AbstractFile, object):
         if file_type not in self.FILES:
             return None
 
-        asset_file_class = artellapipe.AssetsMgr().get_asset_file(file_type=file_type, extension=extension)
+        asset_file_class = artellapipe.FilesMgr().get_asset_file(file_type=file_type, extension=extension)
         if not asset_file_class:
-            LOGGER.warning('File Type: {} | {} not registered in current project!'.format(file_type, extension))
+            LOGGER.warning(
+                'File Type: {} | {} not registered in current project!'.format(file_type, extension))
             return
 
         return asset_file_class(asset=self, **kwargs)
@@ -792,7 +794,8 @@ class AbstractSequence(AbstractFile, object):
 
         sequence_file_class = artellapipe.SequencesMgr().get_sequence_file(file_type=file_type, extension=extension)
         if not sequence_file_class:
-            LOGGER.warning('File Type: {} | {} not registered in current project!'.format(file_type, extension))
+            LOGGER.warning(
+                'File Type: {} | {} not registered in current project!'.format(file_type, extension))
             return
 
         return sequence_file_class(sequence=self)
@@ -867,7 +870,8 @@ class AbstractShot(AbstractFile, object):
 
         sequence_file_class = artellapipe.ShotsMgr().get_shot_file(file_type=file_type, extension=extension)
         if not sequence_file_class:
-            LOGGER.warning('File Type: {} | {} not registered in current project!'.format(file_type, extension))
+            LOGGER.warning(
+                'File Type: {} | {} not registered in current project!'.format(file_type, extension))
             return
 
         return sequence_file_class(shot=self)
