@@ -22,7 +22,7 @@ import artellapipe
 from artellapipe.core import defines
 from artellapipe.libs.artella.core import artellalib
 
-LOGGER = logging.getLogger()
+LOGGER = logging.getLogger('artellapipe')
 
 
 class ArtellaFile(object):
