@@ -17,9 +17,12 @@ import string
 import inspect
 import logging
 
-import tpDccLib as tp
+from Qt.QtGui import *
 
-import artellapipe
+import tpDcc as tp
+from tpDcc.libs.python import decorators
+
+import artellapipe.register
 from artellapipe.core import defines
 
 LOGGER = logging.getLogger()
@@ -166,7 +169,10 @@ class ArtellaDCCNode(object):
         is_referenced = tp.Dcc.node_is_referenced(self._node)
         if not is_referenced:
             self._nodes_list = tp.Dcc.list_children(
-                node=self._node, all_hierarchy=True, full_path=True, children_type='transform')
+                node=self._node, all_hierarchy=True, full_path=True, children_type='transform') or list()
+            self._namespace = tp.Dcc.node_namespace(self.node)
+            if self._namespace:
+                self._valid = True
         else:
             self._loaded = tp.Dcc.node_is_loaded(self._node)
             if self._loaded:
@@ -317,28 +323,6 @@ class ArtellaDCCNode(object):
             tag_node = artellapipe.TagNode(project=self._project, node=self.node, tag_info=tag_info)
             return tag_node
 
-    # def load_shaders(self):
-    #     """
-    #     Loads all the shaders of current asset node
-    #     """
-    #
-    #     tag_node = self.get_tag_node()
-    #     if tag_node:
-    #         shader.load_scene_shaders(project=self._project, tag_nodes=[tag_node])
-    #     else:
-    #         artellapipe.logger.warning('Impossible to load shaders on asset: {}'.format(self.base_name))
-    #
-    # def unload_shaders(self):
-    #     """
-    #     Unloads all the shaders of current asset node
-    #     """
-    #
-    #     tag_node = self.get_tag_node()
-    #     if tag_node:
-    #         shader.unload_shaders(project=self._project, tag_nodes=[tag_node])
-    #     else:
-    #         artellapipe.logger.warning('Impossible to unload shaders on asset: {}'.format(self.base_name))
-
     def has_overrides(self):
         """
         Returns whether current node has overrides or not
@@ -364,7 +348,7 @@ class ArtellaDCCNode(object):
         try:
             from artellapipe.tools.shotmanager.apps import shotassembler
         except ImportError:
-            LOGGER.warning('Impossible to get overrides because Shot Assembler Tools is not available!')
+            # LOGGER.warning('Impossible to get overrides because Shot Assembler Tools is not available!')
             return
 
         if not self.has_overrides():
@@ -467,17 +451,19 @@ class ArtellaDCCNode(object):
 
 
 class ArtellaAssetNode(ArtellaDCCNode, object):
-    def __init__(self, project, node=None, **kwargs):
+    def __init__(self, project, asset, node=None, id=None, **kwargs):
         super(ArtellaAssetNode, self).__init__(project=project, node=node, update_at_init=False)
 
         if node is not None:
             self._name = node
         else:
             self._name = kwargs.get('name', 'New_Asset')
-        self._asset_path = kwargs.get('path', '')             # We use -1, to force the asset path update in first use
         self._category = kwargs.get('category', None)
         self._description = kwargs.get('description', '')
-        self._asset = None
+        self._id = id
+        self._asset = asset
+        if self._asset and not self._id:
+            self._id = asset.get_id()
 
         self._current_version = None
         self._latest_version = None
@@ -485,6 +471,15 @@ class ArtellaAssetNode(ArtellaDCCNode, object):
 
         self.update_info()
 
+    @property
+    def id(self):
+        """
+        Returns the associated asset ID for this node
+        :return: str
+        """
+
+        return self._id
+
     @property
     def name(self):
         """
@@ -501,11 +496,10 @@ class ArtellaAssetNode(ArtellaDCCNode, object):
         :return: str
         """
 
-        # Asset path retrieval is an expensive operation, so we only update it if necessary
-        if self._asset_path == '':
-            self._asset_path = self._get_asset_path()
+        if not self._asset:
+            return
 
-        return self._asset_path
+        return self._asset.get_path()
 
     @property
     def asset(self):
@@ -514,13 +508,26 @@ class ArtellaAssetNode(ArtellaDCCNode, object):
         :return: ArtellaAsset
         """
 
-        # NOTE: We must access asset path property through the property getter to make sure that
-        # file path is updated
-        if not self._asset:
-            self._asset = self._project.find_asset(asset_path=self.asset_path, allow_multiple_instances=False)
-
         return self._asset
 
+    @decorators.abstractmethod
+    def switch_to_proxy(self):
+        """
+        Switches current asset to its lowres version
+        :return:
+        """
+
+        raise NotImplementedError('switch_to_proxy function not implemented!')
+
+    @decorators.abstractmethod
+    def switch_to_hires(self):
+        """
+        Switches current asset to its lowres version
+        :return:
+        """
+
+        raise NotImplementedError('switch_to_hires function not implemented!')
+
     def get_short_name(self, clean=False):
         """
         Returns the short name of the DCC node
@@ -530,22 +537,186 @@ class ArtellaAssetNode(ArtellaDCCNode, object):
 
         return tp.Dcc.node_short_name(self._name).rstrip(string.digits) if clean else tp.Dcc.node_short_name(self._name)
 
-    def _get_asset_path(self):
+    def get_asset_shaders_mapping_file(self):
         """
-        Internal function that returns the asset path of the current node
+        Returns file class of the Asset Shaders Mapping File
+        This file is the one that maps asset geometry to shaders
+        :return:
+        """
+
+        shaders_mapping_file_type = artellapipe.AssetsMgr().get_shaders_mapping_file_type()
+        if not shaders_mapping_file_type:
+            return False
+
+        shaders_mapping_file_class = artellapipe.FilesMgr().get_file_class(shaders_mapping_file_type)
+        if not shaders_mapping_file_class:
+            return False
+
+        shaders_mapping_file = shaders_mapping_file_class(self._asset)
+
+        return shaders_mapping_file
+
+    def get_shaders_files(self, status=defines.ArtellaFileStatus.PUBLISHED):
+        """
+        Returns list of shaders this asset needs to use
+        :return: list(str)
+        """
+
+        shaders = self.get_shaders(status=status)
+        if not shaders:
+            LOGGER.warning('No shaders found ... ({})'.format(status))
+            return
+
+        shaders_files = list()
+        for shader in shaders:
+            shader_file_path = artellapipe.ShadersMgr().get_shader_path(shader)
+            if shader_file_path not in shaders_files:
+                shaders_files.append(shader_file_path)
+
+        return shaders_files
+
+    def load_shaders(self, status=defines.ArtellaFileStatus.PUBLISHED, apply_shaders=True):
+        """
+        Loads all the shaders of current asset node
+        """
+
+        if not tp.is_maya():
+            LOGGER.warning('Shaders loading is only supported in Maya!')
+            return
+
+        return artellapipe.ShadersMgr().load_asset_shaders(self, status=status, apply_shaders=apply_shaders)
+
+    def unload_shaders(self):
+        """
+        Unloads all the shaders of current asset node
+        """
+
+        if not tp.is_maya():
+            LOGGER.warning('Shaders unloading is only supported in Maya!')
+            return
+
+        return artellapipe.ShadersMgr().unload_asset_shaders(self)
+
+    def get_icon(self, force_update=False):
+        """
+        Returns icon associated to this node
+        :param force_update: bool
+        :return: QIcon or None
+        """
+
+        if not self._asset:
+            return
+
+        asset_name = self._asset.get_name()
+        thumbnail_path = artellapipe.AssetsMgr().get_asset_thumbnail_path(asset_name)
+        if thumbnail_path and os.path.isfile(thumbnail_path) and not force_update:
+            return QIcon(QPixmap(thumbnail_path))
+        else:
+            asset_thumb_id = self.get_thumbnail_path()
+            artellapipe.Tracker().download_preview_file_thumbnail(asset_thumb_id, thumbnail_path)
+            if not os.path.isfile(thumbnail_path):
+                return resource.ResourceManager().icon(artellapipe.AssetsMgr().get_default_asset_thumb())
+            else:
+                return QIcon(QPixmap(thumbnail_path))
+
+    def get_renderable_shapes(self, remove_namespace=False, full_path=True):
+        """
+        Returns a list with all renderable shapes of the current asset
+        :param remove_namespace: bool
+        :return: list(str)
+        """
+
+        renderable_shapes = list()
+
+        transform_relatives = tp.Dcc.list_relatives(
+            node=self._node, all_hierarchy=True, full_path=full_path, relative_type='transform',
+            shapes=False, intermediate_shapes=False)
+
+        for obj in transform_relatives:
+            if not tp.Dcc.object_exists(obj):
+                continue
+            shapes = tp.Dcc.list_shapes(node=obj, full_path=full_path, intermediate_shapes=False)
+            if not shapes:
+                continue
+            renderable_shapes.extend(shapes)
+
+        if remove_namespace:
+            renderable_shapes = [tp.Dcc.node_name_without_namespace(shape) for shape in renderable_shapes]
+
+        return list(set(renderable_shapes))
+
+    def get_asset_operator(self):
+        """
+        Returns asset operator of the current node
+        :return: str or None
+        """
+
+        return artellapipe.Arnold().get_asset_operator(self.id, create=False)
+
+    def create_operator_node(self):
+        """
+        Creates asset operator node in current scene
         :return: str
         """
 
-        assets_path = self._project.get_assets_path()
-        if assets_path is None or not os.path.exists(assets_path):
-            raise RuntimeError('Assets Path is not valid: {}'.format(assets_path))
+        return artellapipe.Arnold().get_asset_operator(self.id, connect_to_scene_operator=True, create=True)
 
-        for root, dirs, files in os.walk(assets_path):
-            asset_path = root
-            asset_name = os.path.basename(root)
-            if asset_name == self.get_short_name():
-                return os.path.normpath(asset_path)
+    def get_shape_operator(self, shape_name=None):
+        """
+        Returns asset shape operator of the current node
+        :param shape_name: str
+        :return: str
+        """
 
-            clean_name = self.get_short_name(clean=True)
-            if asset_name == clean_name:
-                return os.path.normpath(asset_path)
+        # TODO: Check if given shape is a shape of the current asset node
+
+        return artellapipe.Arnold().get_asset_shape_operator(self.id, shape_name, create=False)
+
+    def create_shape_operator(self, shape_name=None):
+        """
+        Creates asset shape operator of the current node for the given shape
+        :param shape_name: str
+        :return: str
+        """
+
+        # TODO: Check if given shape is a shape of the current asset node
+
+        return artellapipe.Arnold().get_asset_shape_operator(
+            self.id, shape_name, connect_to_asset_operator=True, create=True)
+
+    def add_shape_operator_assignment(self, assignment_value, shape_name=None):
+        """
+        Adds a new shape operator assignment to given shape operator
+        :param shape_name: str
+        :param assignment_value: str
+        :return:
+        """
+
+        shape_operator = self.get_shape_operator(shape_name)
+        if not shape_operator:
+            LOGGER.warning(
+                'Impossible to set Asset Shape attribute for "{}" because '
+                'asset shape operator for "{}" does not exists!'.format(shape_name, self.id))
+            return
+
+        return artellapipe.Arnold().add_asset_shape_operator_assignment(self.id, shape_name, value=assignment_value)
+
+    def remove_shape_operator_assignment(self, assignment_value, shape_name=None):
+        """
+        Removes an existing shape operator assignment from given shape operator
+        :param shape_name: str
+        :param assignment_value: str
+        :return:
+        """
+
+        shape_operator = self.get_shape_operator(shape_name)
+        if not shape_operator:
+            LOGGER.warning(
+                'Impossible to remove Asset Shape attribute from "{}" because '
+                'asset shape operator for "{}" does not exists!'.format(shape_name, self.id))
+            return
+
+        return artellapipe.Arnold().remove_asset_shape_operator_assignment(self.id, shape_name, value=assignment_value)
+
+
+artellapipe.register.register_class('AssetNode', ArtellaAssetNode)
